#define F_CPU 16000000UL  // Definujeme frekvenciu CPU 16 MHz

#include <avr/io.h>
#include <avr/interrupt.h>

void nastavenie_timerov() {
    // Nastavujeme Timer1 pre PWM na PB1 (OC1A) a PB2 (OC1B)
    TCCR1A |= (1 << COM1A1) | (1 << COM1B1) | (1 << WGM11);
    TCCR1B |= (1 << WGM12) | (1 << WGM13) | (1 << CS10);
    ICR1 = 255;  // Maximlna hodnota pre 8-bitov PWM

    // Nastavujeme Timer2 pre PWM na PB3 (OC2A)
    TCCR2A |= (1 << COM2A1) | (1 << WGM20) | (1 << WGM21);
    TCCR2B |= (1 << CS20);
}

void nastaveniekomunikacie_uart() {
    // Nastavenie UART na 9600 baud
    uint16_t ubrr = F_CPU/16/9600-1;
    UBRR0H = (ubrr >> 8);
    UBRR0L = ubrr;
    UCSR0B |= (1 << RXEN0) | (1 << TXEN0);  
    UCSR0C |= (1 << UCSZ01) | (1 << UCSZ00); 
}

void uart_prenos(uint8_t data) {
    while (!(UCSR0A & (1 << UDRE0)));
    UDR0 = data;
}

uint8_t uart_prijem() {
    while (!(UCSR0A & (1 << RXC0)));
    return UDR0;
}

int main(void) {
    nastavenie_timerov();
    nastaveniekomunikacie_uart();

    DDRB |= (1 << PB1) | (1 << PB2) | (1 << PB3);  // Nastavenie pinov PB1, PB2 a PB3 na vstup

    sei();  // globlne preruenie

    while (1) {
        uint8_t red = 255 - uart_prijem();
        uint8_t green = 255 - uart_prijem();
        uint8_t blue = 255 - uart_prijem();

        OCR2A = red;    // Nastavujeme PWM pre erven LED na PB3
        OCR1B = blue;   // Nastavujeme PWM pre modr LED na PB2
        OCR1A = green;  // Nastavujeme PWM pre zelen LED na PB1
    }
}
